@@ -2,14 +2,9 @@
 # conflicts() in [R] base.
 .conflicts.OK <- TRUE;
 
-# WORKAROUND: In order for the package to work with the most recent
-# version of R devel, which automatically add namespaces to packages
-# who do not have one, we explicitly have specify the following.
-# /HB 2011-08-01
-# From R.utils:
-cat <- R.utils::cat; 
 
-.First.lib <- function(libname, pkgname) {
+## .First.lib <- function(libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
   pkg <- Package(pkgname);
   assign(pkgname, pkg, pos=getPosition(pkg));
 
